/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.core.model;

/**
 * ヘルプ向け XLIFF trans-unit 要素の id 属性を表すクラス。
 * @author KASHIHARA Shinji
 */
public class HelpTransUnitId {

	private static final String PREFIX = "benten://"; //$NON-NLS-1$
	private static final String SEQ_ATTRIBUTE = "?seq="; //$NON-NLS-1$
	private static final String END_MARK = "END"; //$NON-NLS-1$
	private final String path;
	private int seq = 1;
	private int subSeq;
	private int maxSubSeq;

	/**
	 * コンストラクター。
	 * @param path パス
	 */
	public HelpTransUnitId(String path) {
		this.path = path.replace('\\', '/').replaceFirst("^/", ""); //$NON-NLS-1$ //$NON-NLS-2$
	}

	/**
	 * seq のインクリメント。
	 * @return このインスタンス
	 */
	public HelpTransUnitId incrementSeq() {
		seq++;
		subSeq = 0;
		return this;
	}

	/**
	 * seq の枝番をインクリメント。
	 * @param maxSubSeq 枝番の最大値
	 * @return このインスタンス
	 */
	public HelpTransUnitId incrementSubSeq(int maxSubSeq) {
		subSeq++;
		this.maxSubSeq = maxSubSeq;
		return this;
	}

	/**
	 * このインスタンスの文字列表現を取得。
	 */
	@Override
	public String toString() {
		final StringBuilder sb = new StringBuilder();
		sb.append(PREFIX);
		sb.append(path);
		sb.append(SEQ_ATTRIBUTE);
		sb.append(seq);
		if (subSeq != 0) {
			sb.append("-"); //$NON-NLS-1$
			sb.append((subSeq == maxSubSeq) ? END_MARK : String.valueOf(subSeq));
		}
		return sb.toString();
	}

	/**
	 * 指定された id に続きがあるか判定。
	 * @param id id
	 * @return 続きがある場合は true
	 */
	public static boolean hasContinue(String id) {
		return id.startsWith(PREFIX) && id.contains(SEQ_ATTRIBUTE) && id.matches(".+\\d+-\\d+"); //$NON-NLS-1$
	}
}
