/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.preference;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.dialogs.MessageDialogWithToggle;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.ui.IWorkbenchPropertyPage;
import org.eclipse.ui.dialogs.PropertyPage;

import benten.ui.preference.BentenProjectProperty;
import benten.ui.preference.BentenProjectProperty.ProjectProperty;
import benten.ui.views.UiToolkit;

/**
 * 翻訳支援ツール・フィルターのプロパティー・ページです。
 */
public class TwaFilterPropertyPage extends PropertyPage implements IWorkbenchPropertyPage {

	private final UiToolkit toolkit = new UiToolkit();
	private IPreferenceStore projectStore;
	private Button transTargetImportedPromptCheck;
	private Button xliffConvertedPromptCheck;

	@Override
	protected Control createContents(Composite parent) {
		final Composite composite = toolkit.createComposite(parent, 1);
		projectStore = BentenProjectProperty.getStore((IProject) getElement());

		final Group promptGroup = new Group(composite, SWT.BOLD);
		promptGroup.setLayout(toolkit.createGridLayout(2, 5));
		promptGroup.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		promptGroup.setText("実行済みの場合の確認ダイアログ表示");

		transTargetImportedPromptCheck = new Button(promptGroup, SWT.CHECK);
		transTargetImportedPromptCheck.setText("翻訳対象のインポート(&M)");
		transTargetImportedPromptCheck.setSelection(prompt(ProjectProperty.PROMPT_TRANS_TARGET_IMPORTED));

		toolkit.createLabel(promptGroup, getStateMessage(ProjectProperty.TRANS_TARGET_IMPORTED));

		xliffConvertedPromptCheck = new Button(promptGroup, SWT.CHECK);
		xliffConvertedPromptCheck.setText("翻訳対象を XLIFF に変換(&O)");
		xliffConvertedPromptCheck.setSelection(prompt(ProjectProperty.PROMPT_XLIFF_CONVERTED));

		toolkit.createLabel(promptGroup, getStateMessage(ProjectProperty.XLIFF_CONVERTED));

		return composite;
	}

	private String getStateMessage(ProjectProperty property) {
		return projectStore.getBoolean(property.name()) ? "<実行済>" : "<未実行>";
	}

	private boolean prompt(ProjectProperty property) {
		final String prompt = projectStore.getString(property.name());
		return !MessageDialogWithToggle.ALWAYS.equals(prompt);
	}

	private String getValue(Button check) {
		return check.getSelection() ? MessageDialogWithToggle.PROMPT : MessageDialogWithToggle.ALWAYS;
	}

	@Override
	public boolean performOk() {
		projectStore.setValue(ProjectProperty.PROMPT_TRANS_TARGET_IMPORTED.name(),
				getValue(transTargetImportedPromptCheck));
		projectStore.setValue(ProjectProperty.PROMPT_XLIFF_CONVERTED.name(), getValue(xliffConvertedPromptCheck));
		return true;
	}

	@Override
	protected void performDefaults() {
		transTargetImportedPromptCheck.setSelection(true);
		xliffConvertedPromptCheck.setSelection(true);
	}
}
