/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui.dialogs;

import org.eclipse.core.resources.IResource;
import org.eclipse.swt.widgets.Shell;

/**
 * リソース・ファイル選択ダイアログ。
 * @author KASHIHARA Shinji
 */
public class ResourceFileSelectionDialog extends AbstractResourceSelectionDialog {

	private String[] extensions;

	/**
	 * コンストラクター。
	 * @param parentShell 親シェル
	 * @param resources リソース
	 */
	public ResourceFileSelectionDialog(Shell parentShell, IResource... resources) {
		super(parentShell, resources);
		setTitle("ファイルの選択");
		setMessage("ファイルを選択してください。");

	}

	/**
	 * 拡張子のセット。
	 * @param extensions 拡張子
	 */
	public void setExtensions(String... extensions) {
		this.extensions = extensions;
	}

	@Override
	protected boolean acceptSelection(IResource resource) {
		if (resource.getType() == IResource.FILE) {
			if (extensions == null) {
				return true;
			}
			for (final String extension : extensions) {
				final String ext = extension.replace("*", ""); //$NON-NLS-1$ //$NON-NLS-2$
				if (resource.getName().endsWith(ext)) {
					return true;
				}
			}
		}
		return false;
	}
}
