/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui.views;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.swt.widgets.Display;

/**
 * 非同期選択変更アダプター。
 * @author KASHIHARA Shinji
 */
abstract public class AsyncSelectionChangeAdapter implements ISelectionChangedListener {

	/**
	 * {@inheritDoc}
	 */
	final public void selectionChanged(final SelectionChangedEvent event) {
		// 非同期でテンプレート・メソッドを呼び出し
		Display.getCurrent().asyncExec(new Runnable() {
			public void run() {
				final IStructuredSelection selection = (IStructuredSelection) event.getSelection();
				selectionChanged(selection);
			}
		});
	}

	/**
	 * 選択が変更されたときに非同期で呼び出されるテンプレート・メソッド。
	 * @param selection 選択
	 */
	abstract public void selectionChanged(IStructuredSelection selection);
}
